@@ -4,4 +4,4 @@ from .runtime import Options
 from .stage import ReorderStage, Stage
 from .system import Job, Result, System
 from .task import Task
-from .utils import get_logger, progressbar
+from .utils import get_logger, progressbar, process_map
